@@ -1,10 +1,19 @@
 import enum
 import random
 
+
 auto = enum.auto
 
 
-class AutoNameEnum(str, enum.Enum):
+class AutoNameEnumMeta(enum.EnumMeta):
+    def __contains__(cls, member):
+        if isinstance(member, str):
+            return member.upper() in map(str.upper, cls.__members__.keys())
+        else:
+            super().__contains__(member)
+
+
+class AutoNameEnum(str, enum.Enum, metaclass=AutoNameEnumMeta):
     """
     An implementation of enum that automatically assigns the value of each item
     to the lower-case version of the name
@@ -23,14 +32,14 @@ class AutoNameEnum(str, enum.Enum):
         presented by swagger when used in api apps
     """
 
-    def _generate_next_value_(name, start, count, last_values):
+    def _generate_next_value_(name: str, *_):  # type: ignore
         return name.lower()
 
     def __str__(self):
         return self.value
 
     @classmethod
-    def rando(cls, *args):
+    def rando(cls, *_):
         return random.choice([e for e in cls])
 
     @classmethod
@@ -57,5 +66,5 @@ class NoMangleMixin(enum.Enum):
         list of subclasses
     """
 
-    def _generate_next_value_(name, start, count, last_values):
+    def _generate_next_value_(name: str, *_):  # type: ignore
         return name
